# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mercado', 'mercado.vendors']

package_data = \
{'': ['*']}

install_requires = \
['humanize>=4.4.0,<5.0.0',
 'requests>=2.28.1,<3.0.0',
 'rich>=12.6,<14.0',
 'typer>=0.6.1,<0.10.0']

entry_points = \
{'console_scripts': ['mercado = mercado.cli:main']}

setup_kwargs = {
    'name': 'mercado',
    'version': '0.2.1',
    'description': 'All-In-One Development CLI Tools Multi-platform Marketplace',
    'long_description': '# Mercado\nAll-In-One Development CLI Tools Multi-platform Marketplace\n\n<img src="docs/demo.gif" width="900"/>\n\nStop memorizing whether that\'s `apt install` or `brew` or any other package manager that takes too long whenever only to get an outdated tool - and use `mercado` instead!\n\nAll the most used tools by developers like `docker`, `terraform`, and `kubectl`.\n\n- Supports different types of installations\n  - **GitHub releases**\n  - **Hashicorp products**\n  - **URL fetching**\n  - **Customized shell scripts**\n- **Multi-platform multi-architectures** installations\n- Install the **latest artifact** or a specific version\n- HTTP calls with retry mechanismand timeouts\n- Archive unpacking\n- Elaborated logs with timestamps of every step in the process\n- CI first\n  - Every artifact is verified on a daily basis\n  - README is dynamically generated so docs can\'t get broken\n\n\n## Supported Tools\n\n<!-- [[[cog\nimport cog\nfrom textwrap import dedent\nimport subprocess\n\ndef print_command(command):\n    cog.outl(dedent(f"""\n```bash\n$ {command}\n\n{subprocess.getoutput(command)}\n```\n    """))\n\nprint_command("mercado list --names-only --all")\n\n]]] -->\n\n```bash\n$ mercado list --names-only --all\n\nMercado tools \n┏━━━━━━━━━━━━┓\n┃ Name       ┃\n┡━━━━━━━━━━━━┩\n│ aws        │\n│ compose    │\n│ consul     │\n│ cosign     │\n│ docker     │\n│ gh         │\n│ helm       │\n│ k3d        │\n│ k8sgpt     │\n│ k9s        │\n│ kind       │\n│ kubectl    │\n│ minikube   │\n│ packer     │\n│ terraform  │\n│ terragrunt │\n│ tfsec      │\n│ trivy      │\n│ vagrant    │\n│ vault      │\n│ waypoint   │\n└────────────┘\n```\n\n<!-- [[[end]]] -->\n\n## Install\n\n```bash\npython3 -m pip install mercado\n```\n\n## How to use\n\n<!-- [[[cog\nimport cog\nfrom textwrap import dedent\nimport subprocess\n\ndef print_command(command):\n    cog.outl(dedent(f"""\n```bash\n$ {command}\n\n{subprocess.getoutput(command)}\n```\n    """))\n\nprint_command("mercado list --verbose")\n\nprint_command("mercado install gh")\n\nprint_command("mercado is-latest docker")\n\nprint_command("mercado show minikube")\n\nprint_command("mercado list --label k8s --with-labels --all")\n\n]]] -->\n\n```bash\n$ mercado list --verbose\n\n                                            Mercado tools                                             \n┏━━━━━━━━━━━━┳━━━━━━━━━━━┳━━━━━━━━━━━┳━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓\n┃ Name       ┃ Installed ┃ Is Latest ┃ Version ┃ Path                                                ┃\n┡━━━━━━━━━━━━╇━━━━━━━━━━━╇━━━━━━━━━━━╇━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┩\n│ compose    │ ✅        │ 🔼        │ 2.20.3  │ /Users/yuvalgold/.docker/cli-plugins/docker-compose │\n│ gh         │ ✅        │ ✅        │ 2.44.1  │ /Users/yuvalgold/.mercado/gh                        │\n│ k3d        │ ✅        │ ✅        │ 5.6.0   │ /Users/yuvalgold/.mercado/k3d                       │\n│ k8sgpt     │ ✅        │ ✅        │ 0.3.27  │ /Users/yuvalgold/.mercado/k8sgpt                    │\n│ k9s        │ ✅        │ 🔼        │ 0.31.8  │ /Users/yuvalgold/.mercado/k9s                       │\n│ kind       │ ✅        │ 🔼        │ 0.21.0  │ /Users/yuvalgold/.mercado/kind                      │\n│ terragrunt │ ✅        │ 🔼        │ 0.50.3  │ /Users/yuvalgold/.mercado/terragrunt                │\n├────────────┼───────────┼───────────┼─────────┼─────────────────────────────────────────────────────┤\n│ terraform  │ ✅        │ 🔼        │ 1.7.3   │ /Users/yuvalgold/.mercado/terraform                 │\n│ vagrant    │ ✅        │ 🔼        │ 2.3.7   │ /Users/yuvalgold/.mercado/vagrant                   │\n│ vault      │ ✅        │ 🔼        │ 1.14.1  │ /Users/yuvalgold/.mercado/vault                     │\n├────────────┼───────────┼───────────┼─────────┼─────────────────────────────────────────────────────┤\n│ kubectl    │ ✅        │ 🔼        │ 1.28.2  │ /Users/yuvalgold/.mercado/kubectl                   │\n├────────────┼───────────┼───────────┼─────────┼─────────────────────────────────────────────────────┤\n│ aws        │ ✅        │ 🔼        │ 2.15.19 │ /Users/yuvalgold/.mercado/aws                       │\n│ docker     │ ✅        │ ✅        │ 25.0.3  │ /Users/yuvalgold/.mercado/docker                    │\n│ helm       │ ✅        │ 🔼        │ 3.14.0  │ /Users/yuvalgold/.mercado/helm                      │\n└────────────┴───────────┴───────────┴─────────┴─────────────────────────────────────────────────────┘\n```\n\n\n```bash\n$ mercado install gh\n\n[02/22/24 18:07:35] Looking for the latest version of \'gh\'                                                                                         \n[02/22/24 18:07:36] Getting installer for tool \'gh\' with version v2.44.1 for darwin and arm64                                                      \n                    Installing \'gh\'...                                                                                                             \n[02/22/24 18:07:37] Downloading \'gh\' to /var/folders/v5/mbdkcsy10c7b_g08jp498ww00000gn/T/gh_2.44.1_macOS_arm64.zip (size: 10.9 MB)                 \nDownloading... ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━ 100% 0:00:00\n[02/22/24 18:07:40] Unpacking /var/folders/v5/mbdkcsy10c7b_g08jp498ww00000gn/T/gh_2.44.1_macOS_arm64.zip to                                        \n                    /var/folders/v5/mbdkcsy10c7b_g08jp498ww00000gn/T/gh_2.44.1_macOS_arm64                                                         \n                    Copying /var/folders/v5/mbdkcsy10c7b_g08jp498ww00000gn/T/gh_2.44.1_macOS_arm64/gh_2.44.1_macOS_arm64/bin/gh to                 \n                    /Users/yuvalgold/.mercado/gh                                                                                                   \n👍      \'gh\' version v2.44.1 is installed\n```\n\n\n```bash\n$ mercado is-latest docker\n\n👍      You have the latest version of \'docker\' (25.0.3)\n```\n\n\n```bash\n$ mercado show minikube\n\nName: minikube\nStatus: ❌\nRemote Version: \n```\n\n\n```bash\n$ mercado list --label k8s --with-labels --all\n\n                   Mercado tools                   \n┏━━━━━━━━━━┳━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━━━━━━┓\n┃ Name     ┃ Installed ┃ Labels                   ┃\n┡━━━━━━━━━━╇━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━━━━━━┩\n│ helm     │ ✅        │ k8s                      │\n│ k3d      │ ✅        │ k8s,docker,orchestration │\n│ k8sgpt   │ ✅        │ k8s                      │\n│ k9s      │ ✅        │ k8s                      │\n│ kind     │ ✅        │ k8s,docker,orchestration │\n│ kubectl  │ ✅        │ k8s                      │\n│ minikube │ ❌        │ k8s,orchestration        │\n└──────────┴───────────┴──────────────────────────┘\n```\n\n<!-- [[[end]]] -->\n\n## Contributing\n\nPlease see the [CONTRIBUTING guide](https://github.com/alexellis/arkade/blob/master/CONTRIBUTING.md).\n',
    'author': 'YuviGold',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/YuviGold/mercado',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
